@@ -571,13 +571,15 @@ class CustomDist:
         import pymc as pm
         from pytensor.tensor import TensorVariable
 
+
         def logp(value: TensorVariable, mu: TensorVariable) -> TensorVariable:
-            return -(value - mu)**2
+            return -((value - mu) ** 2)
+
 
         with pm.Model():
-            mu = pm.Normal('mu',0,1)
+            mu = pm.Normal("mu", 0, 1)
             pm.CustomDist(
-                'custom_dist',
+                "custom_dist",
                 mu,
                 logp=logp,
                 observed=np.random.randn(100),
@@ -596,20 +598,23 @@ class CustomDist:
         import pymc as pm
         from pytensor.tensor import TensorVariable
 
+
         def logp(value: TensorVariable, mu: TensorVariable) -> TensorVariable:
-            return -(value - mu)**2
+            return -((value - mu) ** 2)
+
 
         def random(
             mu: np.ndarray | float,
             rng: Optional[np.random.Generator] = None,
-            size : Optional[Tuple[int]]=None,
-        ) -> np.ndarray | float :
+            size: Optional[Tuple[int]] = None,
+        ) -> np.ndarray | float:
             return rng.normal(loc=mu, scale=1, size=size)
 
+
         with pm.Model():
-            mu = pm.Normal('mu', 0 , 1)
+            mu = pm.Normal("mu", 0, 1)
             pm.CustomDist(
-                'custom_dist',
+                "custom_dist",
                 mu,
                 logp=logp,
                 random=random,
@@ -629,6 +634,7 @@ class CustomDist:
         import pymc as pm
         from pytensor.tensor import TensorVariable
 
+
         def dist(
             lam: TensorVariable,
             shift: TensorVariable,
@@ -636,6 +642,7 @@ class CustomDist:
         ) -> TensorVariable:
             return pm.Exponential.dist(lam, size=size) + shift
 
+
         with pm.Model() as m:
             lam = pm.HalfNormal("lam")
             shift = -1
