@@ -1,4 +1,4 @@
-#   Copyright 2023 The PyMC Developers
+#   Copyright 2024 The PyMC Developers
 #
 #   Licensed under the Apache License, Version 2.0 (the "License");
 #   you may not use this file except in compliance with the License.
@@ -17,10 +17,11 @@ Created on Mar 7, 2011
 
 @author: johnsalvatier
 """
+
 import warnings
 
+from collections.abc import Iterable
 from functools import partial
-from typing import Iterable
 
 import numpy as np
 import pytensor
@@ -334,7 +335,7 @@ def random_choice(p, size):
         # probability. We must iterate over the elements of all the other
         # dimensions.
         # We first ensure that p is broadcasted to the output's shape
-        size = to_tuple(size) + (1,)
+        size = (*to_tuple(size), 1)
         p = np.broadcast_arrays(p, np.empty(size))[0]
         out_shape = p.shape[:-1]
         # np.random.choice accepts 1D p arrays, so we semiflatten p to
