@@ -50,7 +50,7 @@ from pymc.distributions.shape_utils import (
     rv_size_is_none,
     shape_from_dims,
 )
-from pymc.logprob.abstract import MeasurableVariable, _icdf, _logcdf, _logprob
+from pymc.logprob.abstract import MeasurableOp, _icdf, _logcdf, _logprob
 from pymc.logprob.basic import logp
 from pymc.logprob.rewriting import logprob_rewrites_db
 from pymc.printing import str_for_dist
@@ -97,19 +97,6 @@ class DistributionMeta(ABCMeta):
     """
 
     def __new__(cls, name, bases, clsdict):
-        # Forcefully deprecate old v3 `Distribution`s
-        if "random" in clsdict:
-
-            def _random(*args, **kwargs):
-                warnings.warn(
-                    "The old `Distribution.random` interface is deprecated.",
-                    FutureWarning,
-                    stacklevel=2,
-                )
-                return clsdict["random"](*args, **kwargs)
-
-            clsdict["random"] = _random
-
         rv_op = clsdict.setdefault("rv_op", None)
         rv_type = clsdict.setdefault("rv_type", None)
 
@@ -206,13 +193,6 @@ class DistributionMeta(ABCMeta):
         return new_cls
 
 
-def _make_nice_attr_error(oldcode: str, newcode: str):
-    def fn(*args, **kwargs):
-        raise AttributeError(f"The `{oldcode}` method was removed. Instead use `{newcode}`.`")
-
-    return fn
-
-
 class _class_or_instancemethod(classmethod):
     """Allow a method to be called both as a classmethod and an instancemethod,
     giving priority to the instancemethod.
@@ -228,7 +208,7 @@ class _class_or_instancemethod(classmethod):
         return descr_get(instance, type_)
 
 
-class SymbolicRandomVariable(OpFromGraph):
+class SymbolicRandomVariable(MeasurableOp, OpFromGraph):
     """Symbolic Random Variable
 
     This is a subclasse of `OpFromGraph` which is used to encapsulate the symbolic
@@ -510,14 +490,6 @@ class Distribution(metaclass=DistributionMeta):
                 "for a standalone distribution."
             )
 
-        if "testval" in kwargs:
-            initval = kwargs.pop("testval")
-            warnings.warn(
-                "The `testval` argument is deprecated; use `initval`.",
-                FutureWarning,
-                stacklevel=2,
-            )
-
         if not isinstance(name, string_types):
             raise TypeError(f"Name needs to be a string but got: {name}")
 
@@ -551,10 +523,6 @@ class Distribution(metaclass=DistributionMeta):
         rv_out._repr_latex_ = types.MethodType(
             functools.partial(str_for_dist, formatting="latex"), rv_out
         )
-
-        rv_out.logp = _make_nice_attr_error("rv.logp(x)", "pm.logp(rv, x)")
-        rv_out.logcdf = _make_nice_attr_error("rv.logcdf(x)", "pm.logcdf(rv, x)")
-        rv_out.random = _make_nice_attr_error("rv.random()", "pm.draw(rv)")
         return rv_out
 
     @classmethod
@@ -582,15 +550,6 @@ class Distribution(metaclass=DistributionMeta):
         rv : TensorVariable
             The created random variable tensor.
         """
-        if "testval" in kwargs:
-            kwargs.pop("testval")
-            warnings.warn(
-                "The `.dist(testval=...)` argument is deprecated and has no effect. "
-                "Initial values for sampling/optimization can be specified with `initval` in a modelcontext. "
-                "For using PyTensor's test value features, you must assign the `.tag.test_value` yourself.",
-                FutureWarning,
-                stacklevel=2,
-            )
         if "initval" in kwargs:
             raise TypeError(
                 "Unexpected keyword argument `initval`. "
@@ -617,17 +576,10 @@ class Distribution(metaclass=DistributionMeta):
         create_size = find_size(shape=shape, size=size, ndim_supp=ndim_supp)
         rv_out = cls.rv_op(*dist_params, size=create_size, **kwargs)
 
-        rv_out.logp = _make_nice_attr_error("rv.logp(x)", "pm.logp(rv, x)")
-        rv_out.logcdf = _make_nice_attr_error("rv.logcdf(x)", "pm.logcdf(rv, x)")
-        rv_out.random = _make_nice_attr_error("rv.random()", "pm.draw(rv)")
         _add_future_warning_tag(rv_out)
         return rv_out
 
 
-# Let PyMC know that the SymbolicRandomVariable has a logprob.
-MeasurableVariable.register(SymbolicRandomVariable)
-
-
 @node_rewriter([SymbolicRandomVariable])
 def inline_symbolic_random_variable(fgraph, node):
     """
