@@ -11,6 +11,8 @@
 #   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 #   See the License for the specific language governing permissions and
 #   limitations under the License.
+import warnings
+
 from collections.abc import Callable
 
 import numpy as np
@@ -96,7 +98,7 @@ def find_constrained_prior(
 
         # use these parameters in a model
         with pm.Model():
-            x = pm.Gamma('x', **opt_params)
+            x = pm.Gamma("x", **opt_params)
 
         # specify fixed values before optimization
         opt_params = pm.find_constrained_prior(
@@ -119,12 +121,20 @@ def find_constrained_prior(
         opt_params = pm.find_constrained_prior(
             pm.Exponential,
             lower=0,
-            upper=3.,
+            upper=3.0,
             mass=0.9,
             init_guess={"lam": 1},
             mass_below_lower=0,
         )
     """
+    warnings.warn(
+        "find_constrained_prior is deprecated and will be removed in a future version. "
+        "Please use maxent function from PreliZ. "
+        "https://preliz.readthedocs.io/en/latest/api_reference.html#preliz.unidimensional.maxent",
+        FutureWarning,
+        stacklevel=2,
+    )
+
     assert 0.01 <= mass <= 0.99, (
         "This function optimizes the mass of the given distribution +/- "
         f"1%, so `mass` has to be between 0.01 and 0.99. You provided {mass}."
