@@ -16,18 +16,16 @@ from collections.abc import Sequence
 
 import numpy as np
 
-from pytensor.gradient import DisconnectedType
 from pytensor.graph import Apply, Op
 from pytensor.graph.features import AlreadyThere, Feature
 from pytensor.graph.fg import FunctionGraph
-from pytensor.graph.replace import clone_replace
 from pytensor.graph.rewriting.basic import GraphRewriter, in2out, node_rewriter
-from pytensor.scan.op import Scan
 from pytensor.tensor.variable import TensorVariable
 
-from pymc.logprob.abstract import MeasurableVariable, _logprob
-from pymc.logprob.rewriting import PreserveRVMappings, cleanup_ir_rewrites_db
+from pymc.logprob.abstract import MeasurableOp, ValuedRV, _logprob, valued_rv
+from pymc.logprob.rewriting import cleanup_ir_rewrites_db
 from pymc.logprob.transforms import Transform
+from pymc.logprob.utils import get_related_valued_nodes
 
 
 class TransformedValue(Op):
@@ -44,27 +42,19 @@ class TransformedValue(Op):
     def perform(self, node, inputs, outputs):
         raise NotImplementedError("These `Op`s should be removed from graphs used for computation.")
 
-    def connection_pattern(self, node):
-        return [[True], [False]]
-
     def infer_shape(self, fgraph, node, input_shapes):
         return [input_shapes[0]]
 
-    def grad(self, args, g_outs):
-        return g_outs[0], DisconnectedType()()
-
 
 transformed_value = TransformedValue()
 
 
-class TransformedValueRV(Op):
+class TransformedValueRV(MeasurableOp, Op):
     """A no-op that identifies RVs whose values were transformed.
 
     This is introduced by the `TransformValuesRewrite`
     """
 
-    view_map = {0: [0]}
-
     __props__ = ("transforms",)
 
     def __init__(self, transforms: Sequence[Transform]):
@@ -79,16 +69,10 @@ class TransformedValueRV(Op):
             "`TransformedRV` `Op`s should be removed from graphs used for computation."
         )
 
-    def connection_pattern(self, node):
-        return [[True] for _ in node.outputs]
-
     def infer_shape(self, fgraph, node, input_shapes):
         return input_shapes
 
 
-MeasurableVariable.register(TransformedValueRV)
-
-
 @_logprob.register(TransformedValueRV)
 def transformed_value_logprob(op, values, *rv_outs, use_jacobian=True, **kwargs):
     """Compute the log-probability graph for a `TransformedRV`.
@@ -143,7 +127,7 @@ def transformed_value_logprob(op, values, *rv_outs, use_jacobian=True, **kwargs)
     return logprobs_jac
 
 
-@node_rewriter(tracks=None)
+@node_rewriter(tracks=[ValuedRV])
 def transform_values(fgraph: FunctionGraph, node: Apply) -> list[Apply] | None:
     """Apply transforms to value variables.
 
@@ -156,146 +140,52 @@ def transform_values(fgraph: FunctionGraph, node: Apply) -> list[Apply] | None:
     ``Y`` on the natural scale.
     """
 
-    rv_map_feature: PreserveRVMappings | None = getattr(fgraph, "preserve_rv_mappings", None)
     values_to_transforms: TransformValuesMapping | None = getattr(
         fgraph, "values_to_transforms", None
     )
 
-    if rv_map_feature is None or values_to_transforms is None:
-        return None  # pragma: no cover
-
-    rv_vars = []
-    value_vars = []
-
-    for out in node.outputs:
-        value = rv_map_feature.rv_values.get(out, None)
-        if value is None:
-            continue
-        rv_vars.append(out)
-        value_vars.append(value)
-
-    if not value_vars:
+    if values_to_transforms is None:
         return None
 
-    transforms = [values_to_transforms.get(value_var, None) for value_var in value_vars]
+    rv_node = node.inputs[0].owner
+    valued_nodes = get_related_valued_nodes(rv_node, fgraph)
+    rvs = [valued_var.inputs[0] for valued_var in valued_nodes]
+    values = [valued_var.inputs[1] for valued_var in valued_nodes]
+    transforms = [values_to_transforms.get(value, None) for value in values]
 
     if all(transform is None for transform in transforms):
         return None
 
     transformed_rv_op = TransformedValueRV(transforms)
-    # Clone outputs so that rewrite doesn't reference original variables circularly
-    cloned_outputs = node.clone().outputs
-    transformed_rv_node = transformed_rv_op.make_node(*cloned_outputs)
+    transformed_rv_node = transformed_rv_op.make_node(*rvs)
 
     # We now assume that the old value variable represents the *transformed space*.
     # This means that we need to replace all instance of the old value variable
     # with "inversely/un-" transformed versions of itself.
-    for rv_var, value_var, transform in zip(rv_vars, value_vars, transforms):
-        rv_var_out_idx = node.outputs.index(rv_var)
+    replacements = {}
+    for valued_node, transformed_rv, transform in zip(
+        valued_nodes, transformed_rv_node.outputs, transforms
+    ):
+        rv, value = valued_node.inputs
+        [val_rv] = valued_node.outputs
 
         if transform is None:
-            continue
+            transformed_val = value
 
-        new_value_var = transformed_value(
-            transform.backward(value_var, *node.inputs),
-            value_var,
-        )
+        else:
+            transformed_val = transformed_value(
+                transform.backward(value, *rv.owner.inputs),
+                value,
+            )
 
-        if value_var.name and getattr(transform, "name", None):
-            new_value_var.name = f"{value_var.name}_{transform.name}"
+            value_name = value.name
+            transform_name = getattr(transform, "name", None)
+            if value_name and transform_name:
+                transformed_val.name = f"{value_name}_{transform.name}"
 
-        rv_map_feature.update_rv_maps(
-            rv_var, new_value_var, transformed_rv_node.outputs[rv_var_out_idx]
-        )
+        replacements[val_rv] = valued_rv(transformed_rv, transformed_val)
 
-    return transformed_rv_node.outputs
-
-
-@node_rewriter(tracks=[Scan])
-def transform_scan_values(fgraph: FunctionGraph, node: Apply) -> list[Apply] | None:
-    """Apply transforms to Scan value variables.
-
-    This specialized rewrite is needed because Scan replaces the original value variables
-    by a more complex graph. We want to apply the transform to the original value variable
-    in this subgraph, leaving the rest intact
-    """
-
-    rv_map_feature: PreserveRVMappings | None = getattr(fgraph, "preserve_rv_mappings", None)
-    values_to_transforms: TransformValuesMapping | None = getattr(
-        fgraph, "values_to_transforms", None
-    )
-
-    if rv_map_feature is None or values_to_transforms is None:
-        return None  # pragma: no cover
-
-    rv_vars = []
-    value_vars = []
-
-    for out in node.outputs:
-        value = rv_map_feature.rv_values.get(out, None)
-        if value is None:
-            continue
-        rv_vars.append(out)
-        value_vars.append(value)
-
-    if not value_vars:
-        return None
-
-    transforms = [
-        values_to_transforms.get(rv_map_feature.original_values[value_var], None)
-        for value_var in value_vars
-    ]
-
-    if all(transform is None for transform in transforms):
-        return None
-
-    transformed_rv_op = TransformedValueRV(transforms)
-    # Clone outputs so that rewrite doesn't reference original variables circularly
-    cloned_outputs = node.clone().outputs
-    transformed_rv_node = transformed_rv_op.make_node(*cloned_outputs)
-
-    # We now assume that the old value variable represents the *transformed space*.
-    # This means that we need to replace all instance of the old value variable
-    # with "inversely/un-" transformed versions of itself.
-    for rv_var, value_var, transform in zip(rv_vars, value_vars, transforms):
-        rv_var_out_idx = node.outputs.index(rv_var)
-
-        if transform is None:
-            continue
-
-        # We access the original value variable and apply the transform to that
-        original_value_var = rv_map_feature.original_values[value_var]
-        trans_original_value_var = transform.backward(
-            original_value_var, *transformed_rv_node.inputs
-        )
-
-        # We then replace the reference to the original value variable in the scan value
-        # variable by the back-transform projection computed above
-
-        # The first input corresponds to the original value variable. We are careful to
-        # only clone_replace that part of the graph, as we don't want to break the
-        # mappings between other rvs that are likely to be present in the rest of the
-        # scan value variable graph
-        # TODO: Is it true that the original value only appears in the first input
-        #  and that no other RV can appear there?
-        (trans_original_value_var,) = clone_replace(
-            (value_var.owner.inputs[0],),
-            replace={original_value_var: trans_original_value_var},
-        )
-        transformed_value_var = value_var.owner.clone_with_new_inputs(
-            inputs=[trans_original_value_var] + value_var.owner.inputs[1:]
-        ).default_output()
-
-        new_value_var = transformed_value(transformed_value_var, original_value_var)
-
-        if value_var.name and getattr(transform, "name", None):
-            new_value_var.name = f"{value_var.name}_{transform.name}"
-
-        rv_map_feature.update_rv_maps(
-            rv_var, new_value_var, transformed_rv_node.outputs[rv_var_out_idx]
-        )
-
-    return transformed_rv_node.outputs
+    return replacements
 
 
 class TransformValuesMapping(Feature):
@@ -315,7 +205,6 @@ class TransformValuesRewrite(GraphRewriter):
     r"""Transforms value variables according to a map."""
 
     transform_rewrite = in2out(transform_values, ignore_newtrees=True)
-    scan_transform_rewrite = in2out(transform_scan_values, ignore_newtrees=True)
 
     def __init__(
         self,
@@ -340,7 +229,6 @@ class TransformValuesRewrite(GraphRewriter):
 
     def apply(self, fgraph: FunctionGraph):
         self.transform_rewrite.rewrite(fgraph)
-        self.scan_transform_rewrite.rewrite(fgraph)
 
 
 @node_rewriter([TransformedValue])
