@@ -156,19 +156,25 @@ def extract_obs_data(x: TensorVariable) -> np.ndarray:
     TypeError
 
     """
+    # TODO: These data functions should be in data.py or model/core.py
+    from pymc.data import MinibatchOp
+
     if isinstance(x, Constant):
         return x.data
     if isinstance(x, SharedVariable):
         return x.get_value()
-    if x.owner and isinstance(x.owner.op, Elemwise) and isinstance(x.owner.op.scalar_op, Cast):
-        array_data = extract_obs_data(x.owner.inputs[0])
-        return array_data.astype(x.type.dtype)
-    if x.owner and isinstance(x.owner.op, AdvancedIncSubtensor | AdvancedIncSubtensor1):
-        array_data = extract_obs_data(x.owner.inputs[0])
-        mask_idx = tuple(extract_obs_data(i) for i in x.owner.inputs[2:])
-        mask = np.zeros_like(array_data)
-        mask[mask_idx] = 1
-        return np.ma.MaskedArray(array_data, mask)
+    if x.owner is not None:
+        if isinstance(x.owner.op, Elemwise) and isinstance(x.owner.op.scalar_op, Cast):
+            array_data = extract_obs_data(x.owner.inputs[0])
+            return array_data.astype(x.type.dtype)
+        if isinstance(x.owner.op, MinibatchOp):
+            return extract_obs_data(x.owner.inputs[x.owner.outputs.index(x)])
+        if isinstance(x.owner.op, AdvancedIncSubtensor | AdvancedIncSubtensor1):
+            array_data = extract_obs_data(x.owner.inputs[0])
+            mask_idx = tuple(extract_obs_data(i) for i in x.owner.inputs[2:])
+            mask = np.zeros_like(array_data)
+            mask[mask_idx] = 1
+            return np.ma.MaskedArray(array_data, mask)
 
     raise TypeError(f"Data cannot be extracted from {x}")
 
@@ -514,20 +520,18 @@ def join_nonshared_inputs(
         y = pt.vector("y")
         # Original output
         out = x + y
-        print(out.eval({x: np.array(1), y: np.array([1, 2, 3])})) # [2, 3, 4]
+        print(out.eval({x: np.array(1), y: np.array([1, 2, 3])}))  # [2, 3, 4]
 
         # New output and inputs
         [new_out], joined_inputs = join_nonshared_inputs(
-            point={ # Only shapes matter
+            point={  # Only shapes matter
                 "x": np.zeros(()),
                 "y": np.zeros(3),
             },
             outputs=[out],
             inputs=[x, y],
         )
-        print(new_out.eval({
-            joined_inputs: np.array([1, 1, 2, 3]),
-        })) # [2, 3, 4]
+        print(new_out.eval({joined_inputs: np.array([1, 1, 2, 3])}))  # [2, 3, 4]
 
     Join the input value variables of a model logp.
 
@@ -538,15 +542,19 @@ def join_nonshared_inputs(
         with pm.Model() as model:
             mu_pop = pm.Normal("mu_pop")
             sigma_pop = pm.HalfNormal("sigma_pop")
-            mu = pm.Normal("mu", mu_pop, sigma_pop, shape=(3, ))
+            mu = pm.Normal("mu", mu_pop, sigma_pop, shape=(3,))
 
             y = pm.Normal("y", mu, 1.0, observed=[0, 1, 2])
 
-        print(model.compile_logp()({
-            "mu_pop": 0,
-            "sigma_pop_log__": 1,
-            "mu": [0, 1, 2],
-        })) # -12.691227342634292
+        print(
+            model.compile_logp()(
+                {
+                    "mu_pop": 0,
+                    "sigma_pop_log__": 1,
+                    "mu": [0, 1, 2],
+                }
+            )
+        )  # -12.691227342634292
 
         initial_point = model.initial_point()
         inputs = model.value_vars
@@ -557,9 +565,13 @@ def join_nonshared_inputs(
             inputs=inputs,
         )
 
-        print(logp.eval({
-            joined_inputs: [0, 1, 0, 1, 2],
-        })) # -12.691227342634292
+        print(
+            logp.eval(
+                {
+                    joined_inputs: [0, 1, 0, 1, 2],
+                }
+            )
+        )  # -12.691227342634292
 
     Same as above but with the `mu_pop` value variable being shared.
 
@@ -574,14 +586,16 @@ def join_nonshared_inputs(
             point=initial_point,
             outputs=[model.logp()],
             inputs=other_inputs,
-            shared_inputs={
-                mu_pop_input: shared_mu_pop_input
-            },
+            shared_inputs={mu_pop_input: shared_mu_pop_input},
         )
 
-        print(logp.eval({
-            other_joined_inputs: [1, 0, 1, 2],
-        })) # -12.691227342634292
+        print(
+            logp.eval(
+                {
+                    other_joined_inputs: [1, 0, 1, 2],
+                }
+            )
+        )  # -12.691227342634292
     """
     if not inputs:
         raise ValueError("Empty list of input variables.")
@@ -666,6 +680,9 @@ class GeneratorOp(Op):
     __props__ = ("generator",)
 
     def __init__(self, gen, default=None):
+        warnings.warn(
+            "generator data is deprecated and will be removed in a future release", FutureWarning
+        )
         from pymc.data import GeneratorAdapter
 
         super().__init__()
