@@ -53,8 +53,9 @@ class SMC_KERNEL(ABC):
         initialize_population
             Choose initial population of SMC particles. Should return a dictionary
             with {var.name : numpy array of size (draws, var.size)}. Defaults
-            to sampling from the prior distribution. This method is only called
-            if `start` is not specified.
+            to sampling from the prior distribution, except for parameters which have custom
+            `initval`, in which case that value is used for all SMC particles.
+            This method is only called if `start` is not specified.
 
         _initialize_kernel : default
             Creates initial population of particles in the variable
@@ -144,7 +145,8 @@ class SMC_KERNEL(ABC):
             independent chains. Defaults to 2000.
         start : dict, or array of dict, default None
             Starting point in parameter space. It should be a list of dict with length `chains`.
-            When None (default) the starting point is sampled from the prior distribution.
+            When None (default) the starting point is sampled from the prior distribution, except
+            for parameters with a custom `initval`, in which case that value is used.
         model : Model (optional if in ``with`` context).
         random_seed : int, array_like of int, RandomState or Generator, optional
             Value used to initialize the random number generator.
@@ -193,10 +195,13 @@ class SMC_KERNEL(ABC):
             )
 
             model = self.model
+
             prior_expression = make_initial_point_expression(
                 free_rvs=model.free_RVs,
                 rvs_to_transforms=model.rvs_to_transforms,
-                initval_strategies={},
+                initval_strategies={
+                    **model.rvs_to_initial_values,
+                },
                 default_strategy="prior",
                 return_transformed=True,
             )
