@@ -433,7 +433,7 @@ class TestMixture:
         cov2 = np.diag([2.5, 3.5])
         obs = np.asarray([[0.5, 0.5], mu1, mu2])
         with Model() as model:
-            w = Dirichlet("w", floatX(np.ones(2)), transform=None, shape=(2,))
+            w = Dirichlet("w", floatX(np.ones(2)), default_transform=None, shape=(2,))
             mvncomp1 = MvNormal.dist(mu=mu1, cov=cov1)
             mvncomp2 = MvNormal.dist(mu=mu2, cov=cov2)
             y = Mixture("x_obs", w, [mvncomp1, mvncomp2], observed=obs)
@@ -561,7 +561,7 @@ class TestMixture:
 
         n_samples = 30
         with model:
-            prior = sample_prior_predictive(samples=n_samples, return_inferencedata=False)
+            prior = sample_prior_predictive(draws=n_samples, return_inferencedata=False)
             ppc = sample_posterior_predictive(
                 n_samples * [self.get_initial_point(model)], return_inferencedata=False
             )
@@ -607,7 +607,7 @@ class TestMixture:
 
         n_samples = 20
         with model:
-            prior = sample_prior_predictive(samples=n_samples, return_inferencedata=False)
+            prior = sample_prior_predictive(draws=n_samples, return_inferencedata=False)
             ppc = sample_posterior_predictive(
                 n_samples * [self.get_initial_point(model)], return_inferencedata=False
             )
@@ -630,19 +630,27 @@ class TestMixture:
         with Model() as model:
             # mixtures components
             g_comp = Normal.dist(
-                mu=Exponential("mu_g", lam=1.0, shape=nbr, transform=None), sigma=1, shape=nbr
+                mu=Exponential("mu_g", lam=1.0, shape=nbr, default_transform=None),
+                sigma=1,
+                shape=nbr,
             )
             l_comp = LogNormal.dist(
-                mu=Exponential("mu_l", lam=1.0, shape=nbr, transform=None), sigma=1, shape=nbr
+                mu=Exponential("mu_l", lam=1.0, shape=nbr, default_transform=None),
+                sigma=1,
+                shape=nbr,
             )
             # weight vector for the mixtures
-            g_w = Dirichlet("g_w", a=floatX(np.ones(nbr) * 0.0000001), transform=None, shape=(nbr,))
-            l_w = Dirichlet("l_w", a=floatX(np.ones(nbr) * 0.0000001), transform=None, shape=(nbr,))
+            g_w = Dirichlet(
+                "g_w", a=floatX(np.ones(nbr) * 0.0000001), default_transform=None, shape=(nbr,)
+            )
+            l_w = Dirichlet(
+                "l_w", a=floatX(np.ones(nbr) * 0.0000001), default_transform=None, shape=(nbr,)
+            )
             # mixture components
             g_mix = Mixture.dist(w=g_w, comp_dists=g_comp)
             l_mix = Mixture.dist(w=l_w, comp_dists=l_comp)
             # mixture of mixtures
-            mix_w = Dirichlet("mix_w", a=floatX(np.ones(2)), transform=None, shape=(2,))
+            mix_w = Dirichlet("mix_w", a=floatX(np.ones(2)), default_transform=None, shape=(2,))
             mix = Mixture("mix", w=mix_w, comp_dists=[g_mix, l_mix], observed=np.exp(norm_x))
 
         test_point = model.initial_point()
@@ -1028,7 +1036,7 @@ class TestMixtureSameFamily:
                 comp_dists=comp_dists,
                 shape=(*batch_shape, 3),
             )
-            prior = sample_prior_predictive(samples=self.n_samples, return_inferencedata=False)
+            prior = sample_prior_predictive(draws=self.n_samples, return_inferencedata=False)
 
         assert prior["mixture"].shape == (self.n_samples, *batch_shape, 3)
         assert draw(mixture, draws=self.size).shape == (self.size, *batch_shape, 3)
@@ -1060,7 +1068,7 @@ class TestMixtureSameFamily:
         with Model() as model:
             comp_dists = MvNormal.dist(mu=mu, chol=chol, shape=(self.mixture_comps, 3))
             mixture = Mixture("mixture", w=w, comp_dists=comp_dists, shape=(3,))
-            prior = sample_prior_predictive(samples=self.n_samples, return_inferencedata=False)
+            prior = sample_prior_predictive(draws=self.n_samples, return_inferencedata=False)
 
         assert prior["mixture"].shape == (self.n_samples, 3)
         assert draw(mixture, draws=self.size).shape == (self.size, 3)
@@ -1084,7 +1092,7 @@ class TestMixtureSameFamily:
             mu = Gamma("mu", 1.0, 1.0, shape=2)
             comp_dists = Poisson.dist(mu, shape=2)
             mix = Mixture("mix", w=np.ones(2) / 2, comp_dists=comp_dists, shape=(1000,))
-            prior = sample_prior_predictive(samples=self.n_samples, return_inferencedata=False)
+            prior = sample_prior_predictive(draws=self.n_samples, return_inferencedata=False)
 
         assert prior["mix"].shape == (self.n_samples, 1000)
 
@@ -1306,9 +1314,9 @@ class TestMixtureDefaultTransforms:
         with Model() as model:
             lower = Normal("lower", 0.5)
             upper = Uniform("upper", 0, 1)
-            uniform = Uniform("uniform", -pt.abs(lower), pt.abs(upper), transform=None)
+            uniform = Uniform("uniform", -pt.abs(lower), pt.abs(upper), default_transform=None)
             triangular = Triangular(
-                "triangular", -pt.abs(lower), pt.abs(upper), c=0.25, transform=None
+                "triangular", -pt.abs(lower), pt.abs(upper), c=0.25, default_transform=None
             )
             comp_dists = [
                 Uniform.dist(-pt.abs(lower), pt.abs(upper)),
@@ -1334,7 +1342,7 @@ class TestMixtureDefaultTransforms:
             halfnorm = HalfNormal("halfnorm")
             comp_dists = [HalfNormal.dist(), HalfNormal.dist()]
             mix_transf = Mixture("mix_transf", w=[0.5, 0.5], comp_dists=comp_dists)
-            mix = Mixture("mix", w=[0.5, 0.5], comp_dists=comp_dists, transform=None)
+            mix = Mixture("mix", w=[0.5, 0.5], comp_dists=comp_dists, default_transform=None)
 
         logp_fn = m.compile_logp(vars=[halfnorm, mix_transf, mix], sum=False)
         test_point = {"halfnorm_log__": 1, "mix_transf_log__": 1, "mix": np.exp(1)}
