@@ -451,7 +451,7 @@ class TestPowerRVTransform:
         # ICDF is not implemented for chisquare, so we have to test with another identity
         # sqrt(exponential(lam)) = rayleigh(1 / sqrt(2 * lam))
         lam = 2.5
-        y_rv = pt.sqrt(pt.random.exponential(scale=1 / lam))
+        y_rv = pt.sqrt(pt.random.exponential(scale=1 / lam, size=(4,)))
         y_vv = x_rv.clone()
         y_icdf_fn = pytensor.function([y_vv], icdf(y_rv, y_vv))
         q_test_val = np.r_[0.2, 0.5, 0.7, 0.9]
@@ -693,37 +693,42 @@ def test_not_implemented_discrete_rv_transform():
 
 def test_negated_discrete_rv_transform():
     p = 0.7
-    rv = -Bernoulli.dist(p=p)
+    rv = -Bernoulli.dist(p=p, shape=(4,))
     vv = rv.type()
-    logp_fn = pytensor.function([vv], logp(rv, vv))
 
     # A negated Bernoulli has pmf {p if x == -1; 1-p if x == 0; 0 otherwise}
-    assert logp_fn(-2) == -np.inf
-    np.testing.assert_allclose(logp_fn(-1), np.log(p))
-    np.testing.assert_allclose(logp_fn(0), np.log(1 - p))
-    assert logp_fn(1) == -np.inf
+    logp_fn = pytensor.function([vv], logp(rv, vv))
+    np.testing.assert_allclose(
+        logp_fn([-2, -1, 0, 1]), [-np.inf, np.log(p), np.log(1 - p), -np.inf]
+    )
 
-    # Logcdf and icdf not supported yet
-    for func in (logcdf, icdf):
-        with pytest.raises(NotImplementedError):
-            func(rv, 0)
+    logcdf_fn = pytensor.function([vv], logcdf(rv, vv))
+    np.testing.assert_allclose(logcdf_fn([-2, -1, 0, 1]), [-np.inf, np.log(p), 0, 0])
+
+    with pytest.raises(NotImplementedError):
+        icdf(rv, [-2, -1, 0, 1])
 
 
 def test_shifted_discrete_rv_transform():
     p = 0.7
     rv = Bernoulli.dist(p=p) + 5
     vv = rv.type()
-    rv_logp_fn = pytensor.function([vv], logp(rv, vv))
 
+    rv_logp_fn = pytensor.function([vv], logp(rv, vv))
     assert rv_logp_fn(4) == -np.inf
     np.testing.assert_allclose(rv_logp_fn(5), np.log(1 - p))
     np.testing.assert_allclose(rv_logp_fn(6), np.log(p))
     assert rv_logp_fn(7) == -np.inf
 
-    # Logcdf and icdf not supported yet
-    for func in (logcdf, icdf):
-        with pytest.raises(NotImplementedError):
-            func(rv, 0)
+    rv_logcdf_fn = pytensor.function([vv], logcdf(rv, vv))
+    assert rv_logcdf_fn(4) == -np.inf
+    np.testing.assert_allclose(rv_logcdf_fn(5), np.log(1 - p))
+    np.testing.assert_allclose(rv_logcdf_fn(6), 0)
+    assert rv_logcdf_fn(7) == 0
+
+    # icdf not supported yet
+    with pytest.raises(NotImplementedError):
+        icdf(rv, 0)
 
 
 @pytest.mark.xfail(reason="Check not implemented yet")
